| Title: | Joint estimation of initial incidence and reproduction number |
|---|---|
| Description: | Provides a Stan implementation of a method to jointly estimate incidence and reproduction number. |
| Authors: | Sangeeta Bhatia [aut, cre], Pierre Nouvellet [aut], Anne Cori [aut], Jack Wardle [aut] |
| Maintainer: | Sangeeta Bhatia <[email protected]> |
| License: | MIT |
| Version: | 0.0.1 |
| Built: | 2026-05-25 06:12:42 UTC |
| Source: | https://github.com/mrc-ide/jointlyr |
A DESCRIPTION OF THE PACKAGE
Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.21.2. https://mc-stan.org
Joint estimation of initial incidence and reproduction number
jointly_estimate(window, window_back, incid, si_distr, ...)jointly_estimate(window, window_back, incid, si_distr, ...)
window |
length of the window used for estimation. If you have the full incidence time-series, only data in this window are used for estimatiom. |
window_back |
length of time for which incidence should be estimated. |
incid |
Incidence used to fit the model. Numeric vector of
length |
si_distr |
Discretised serial interval distribution |
... |
Arguments passed to |
an object of class stanfit
Sangeeta Bhatia